@@ -6,7 +6,7 @@ from typing import NamedTuple
 import tensorflow as tf
 from model_data_util.create_tt_data.model_data_convert import convertRawDataToModel
 
-from check_environment import check_env_info
+from TTBenchmark.check_environment import check_env_info
 from constant import GDRIVE_PATH
 
 
